<?php

/**
 * The file that defines admin navigation tabs
 *
 * @link  https://furgonetka.pl
 * @since 1.0.0
 *
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/admin_tabs
 */

/**
 * Class Furgonetka_Admin_Nav - managing navigation in admin options page
 *
 * @since      1.0.0
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/admin_tabs
 * @author     Furgonetka.pl <woocommerce@furgonetka.pl>
 */
class Furgonetka_Admin_Nav extends Furgonetka_Admin_Tabs
{
    /**
     * Admin nav views
     *
     * @var \Furgonetka_Navigation()
     */
    public $view;

    /**
     * Error message
     *
     * @var string
     */
    private $furgonetka_errors;

    /**
     * Message
     *
     * @var string
     */
    private $furgonetka_message;

    /**
     * Furgonetka_Admin_Nav constructor.
     *
     * @param string $tab                 - current tab.
     * @param string $furgonetka_form_url - form url.
     * @param mixed  $furgonetka_errors   - error message.
     * @param mixed  $furgonetka_message  - message.
     */
    public function __construct( string $tab, string $furgonetka_form_url, $furgonetka_errors, $furgonetka_message )
    {
        parent::__construct( $tab, $furgonetka_form_url );
        $this->furgonetka_errors  = $furgonetka_errors;
        $this->furgonetka_message = $furgonetka_message;
    }

    /**
     * Include view file
     *
     * @return void
     */
    public function include_view()
    {
        require_once plugin_dir_path( dirname( __FILE__ ) ) . '/view/class-furgonetka-navigation.php';
        $this->view = new Furgonetka_Navigation();
    }

    /**
     * Render template
     *
     * @return void
     */
    public function render_template()
    {
        $this->view->render_nav( $this->tab );
        $this->view->render_admin_notices_area( $this->tab, $this->furgonetka_errors, $this->furgonetka_message );
    }
}
