<?php

/**
 * The file that defines class for registering new tabs
 *
 * @link  https://furgonetka.pl
 * @since 1.0.0
 *
 * @package    Furgonetka
 * @subpackage Furgonetka/includes
 */

/**
 * Class Furgonetka_Admin_Area_Controller
 * Manage html for plugins options page
 * To add new tab register new class in register_tabs() and add new tab in Furgonetka_Navigation() -> render_nav()
 *
 * @since      1.0.0
 * @package    Furgonetka
 * @subpackage Furgonetka/includes
 * @author     Furgonetka.pl <woocommerce@furgonetka.pl>
 */
class Furgonetka_Admin_Area_Controller
{
    /**
     * Collection of tabs controllers
     *
     * @var array
     */
    private $controllers = array();

    /**
     * Current tab name
     *
     * @var string
     */
    private $tab = '';

    /**
     * Navigation controller
     *
     * @var Furgonetka_Admin_Nav
     */
    private $nav;

    /**
     * From url
     *
     * @var string
     */
    private $furgonetka_form_url = '';

    /**
     * Error message
     *
     * @var string
     */
    public $furgonetka_errors;

    /**
     * Message
     *
     * @var string
     */
    public $furgonetka_message;

    /**
     * Constructor - register tabs and navigation
     *
     * @param string $tab                 - tab name.
     * @param string $furgonetka_form_url - form url.
     * @param string $furgonetka_errors   - error msg.
     * @param string $furgonetka_message  - message.
     */
    public function __construct( $tab, $furgonetka_form_url, $furgonetka_errors, $furgonetka_message )
    {
        $this->tab                 = $tab;
        $this->furgonetka_form_url = $furgonetka_form_url;
        $this->furgonetka_errors   = $furgonetka_errors;
        $this->furgonetka_message  = $furgonetka_message;

        $this->register_tabs();
        $this->register_navigation();
    }

    /**
     * Register nav
     *
     * @return void
     */
    private function register_navigation(): void
    {
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/admin_tabs/class-furgonetka-admin-nav.php';
        $this->nav = new Furgonetka_Admin_Nav(
            $this->tab,
            $this->furgonetka_form_url,
            $this->furgonetka_errors,
            $this->furgonetka_message
        );
    }

    /**
     * Register tabs
     *
     * @return void
     */
    private function register_tabs(): void
    {
        /**
         * Include Abstract class
         */
        require_once FURGONETKA_PLUGIN_DIR . 'includes/admin_tabs/class-furgonetka-admin-tabs.php';
        /**
         * API settings tab
         */
        require_once FURGONETKA_PLUGIN_DIR . 'includes/admin_tabs/class-furgonetka-api-settings-tab.php';
        $this->controllers['furgonetka'] = new Furgonetka_Api_Settings_Tab( $this->tab, $this->furgonetka_form_url );
        /**
         * Sender Data tab
         */
        require_once FURGONETKA_PLUGIN_DIR . 'includes/admin_tabs/class-furgonetka-sender-info-tab.php';
        $this->controllers['sender_info'] = new Furgonetka_Sender_Info_Tab( $this->tab, $this->furgonetka_form_url );
        /**
         * Map settings tab
         */
        require_once FURGONETKA_PLUGIN_DIR . 'includes/admin_tabs/class-furgonetka-attach-map-tab.php';
        $this->controllers['attach_map'] = new Furgonetka_Attach_Map_Tab( $this->tab, $this->furgonetka_form_url );
        /**
         * Advanced settings tab
         */
        require_once FURGONETKA_PLUGIN_DIR . 'includes/admin_tabs/class-furgonetka-advanced-settings-tab.php';
        $this->controllers['advanced_settings'] = new Furgonetka_Advanced_Settings_Tab( $this->tab, $this->furgonetka_form_url );
    }

    /**
     * Render tabs
     */
    public function render()
    {
        $this->nav->render_template();
        $this->controllers[ "{$this->tab}" ]->render_template();
    }
}
