<?php

/**
 * The file that defines view for api setting in cms
 *
 * @link  https://furgonetka.pl
 * @since 1.0.0
 *
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 */

/**
 * Class Furgonetka_Admin_Advanced_Settings_View - views for Admin options page - Advanced settings
 *
 * @since      1.0.0
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 * @author     Furgonetka.pl <woocommerce@furgonetka.pl>
 */
class Furgonetka_Admin_Advanced_Settings_View
{
    /**
     * Reder Admin navigation
     *
     * @param  string $tab             - tab.
     * @param  string $tab_api_account - tab api account.
     * @param  string $tab_sender_info - tab sender info.
     * @param  string $tab_attach_map  - tab attach map.
     * @param  string $tab_advanced    - tab advanced settings.
     * @return void
     */
    public function render_admin_navigation( $tab, $tab_api_account, $tab_sender_info, $tab_attach_map, $tab_advanced )
    {
        ?>
        <nav class="nav-tab-wrapper woo-nav-tab-wrapper">
            <a
                    href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_api_account ) ); ?>"
                    class="nav-tab <?php echo ( $tab === $tab_api_account || ! isset( $tab ) ) ? 'nav-tab-active' : ''; ?>"
            >
                <?php esc_attr_e( 'API account', 'furgonetka' ); ?>
            </a>
            <?php if ( Furgonetka_Admin::is_account_active() ) : ?>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_sender_info ) ); ?>"
                        class="nav-tab <?php echo ( $tab === $tab_sender_info ) ? 'nav-tab-active' : ''; ?>"
                >
                    <?php esc_attr_e( 'Sender info', 'furgonetka' ); ?>
                </a>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_attach_map ) ); ?>"
                        class="nav-tab <?php echo esc_html( ( $tab === $tab_attach_map ) ? 'nav-tab-active' : '' ); ?>"
                >
                    <?php esc_attr_e( 'Attach map', 'furgonetka' ); ?>
                </a>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_advanced ) ); ?>"
                        class="nav-tab <?php echo esc_html( ( $tab === $tab_attach_map ) ? 'nav-tab-active' : '' ); ?>"
                >
                    <?php esc_attr_e( 'Advanced', 'furgonetka' ); ?>
                </a>
            <?php endif; ?>
        </nav>
        <?php
    }

    /**
     * Render admin heading
     *
     * @return void
     */
    public function render_admin_heading()
    {
        ?>
        <h1 class="screen-reader-text"><?php esc_attr_e( 'Advanced settings', 'furgonetka' ); ?></h1>
        <p>
            <?php esc_attr_e( 'Setting below are for advanced users with at least basic programming/web development knowledge.', 'furgonetka' ); ?><br>

        </p>
        <?php
    }

    /**
     * Render admin account summary
     *
     * @return void
     */
    public function render_admin_settings_fields( $furgonetka_form_url, $tab_advanced )
    {
        ?>
        <form method="post" action="<?php echo esc_html( $furgonetka_form_url . '&tab=' . $tab_advanced ); ?>">
            <input type="hidden" name="furgonetkaAction" value="save_advanced"/>
            <?php wp_nonce_field(); ?>
            <h2><?php esc_attr_e( 'Portmonetka', 'furgonetka' ); ?></h2>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row">
                            <label for="clientID">
                                <?php esc_attr_e( 'Portmonetka product button parent html selector', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="portmonetka_product_selector"
                                    type="text"
                                    id="productSelector"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_portmonetka_product_selector() ); ?>"
                                    class="regular-text"
                            >
                            <p>
                                <?php esc_attr_e( 'Use only when default button placement is wrong, will display button within woocommerce single product page.', 'furgonetka' ); ?><br>
                                <?php esc_attr_e( 'Element must be inside woocommerce add to cart form', 'furgonetka' ); ?>
                            </p>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="clientSecret">
                                <?php esc_attr_e( 'Portmonetka cart button parent html selector', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="portmonetka_cart_selector"
                                    type="text"
                                    id="cartSelector"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_portmonetka_cart_selector() ); ?>"
                                    class="regular-text"
                            >
                            <p>
                                <?php esc_attr_e( 'Use only when default button placement is wrong, will display button within woocommerce cart page.', 'furgonetka' ); ?>
                            </p>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="clientSecret">
                                <?php esc_attr_e( 'Portmonetka mini cart button parent html selector', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="portmonetka_minicart_selector"
                                    type="text"
                                    id="miniCartSelector"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_portmonetka_minicart_selector() ); ?>"
                                    class="regular-text"
                            >
                            <p>
                                <?php esc_attr_e( 'Use only when default button placement is wrong, will display button within woocommerce mini cart widget.', 'furgonetka' ); ?>
                            </p>
                        </td>
                    </tr>
                </tbody>
            </table>
            <p class="submit">
                <input
                        type="submit"
                        name="submit"
                        class="button button-primary"
                        value="<?php esc_attr_e( 'Save', 'furgonetka' ); ?>"
                >
            </p>
        </form>
        <?php
    }
}
