<?php

/**
 * The file that defines view for api setting in cms
 *
 * @link  https://furgonetka.pl
 * @since 1.0.0
 *
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 */

/**
 * Class Furgonetka_Admin_Api_Settings_View - views for Admin options page - Api settings
 *
 * @since      1.0.0
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 * @author     Furgonetka.pl <woocommerce@furgonetka.pl>
 */
class Furgonetka_Admin_Api_Settings_View
{
    /**
     * Reder Admin navigation
     *
     * @param  string $tab             - tab.
     * @param  string $tab_api_account - tab api account.
     * @param  string $tab_sender_info - tab sender info.
     * @param  string $tab_attach_map  - tab attach map.
     * @param  string $tab_advanced    - tab advanced settings.
     * @return void
     */
    public function render_admin_navigation( $tab, $tab_api_account, $tab_sender_info, $tab_attach_map, $tab_advanced )
    {
        ?>
        <nav class="nav-tab-wrapper woo-nav-tab-wrapper">
            <a
                    href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_api_account ) ); ?>"
                    class="nav-tab <?php echo ( $tab === $tab_api_account || ! isset( $tab ) ) ? 'nav-tab-active' : ''; ?>"
            >
                <?php esc_attr_e( 'API account', 'furgonetka' ); ?>
            </a>
            <?php if ( Furgonetka_Admin::is_account_active() ) : ?>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_sender_info ) ); ?>"
                        class="nav-tab <?php echo ( $tab === $tab_sender_info ) ? 'nav-tab-active' : ''; ?>"
                >
                    <?php esc_attr_e( 'Sender info', 'furgonetka' ); ?>
                </a>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_attach_map ) ); ?>"
                        class="nav-tab <?php echo esc_html( ( $tab === $tab_attach_map ) ? 'nav-tab-active' : '' ); ?>"
                >
                    <?php esc_attr_e( 'Attach map', 'furgonetka' ); ?>
                </a>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=' . $tab_advanced ) ); ?>"
                        class="nav-tab <?php echo esc_html( ( $tab === $tab_advanced ) ? 'nav-tab-active' : '' ); ?>"
                >
                    <?php esc_attr_e( 'Advanced', 'furgonetka' ); ?>
                </a>
            <?php endif; ?>
        </nav>
        <?php
    }

    /**
     * Render admin heading
     *
     * @return void
     */
    public function render_admin_heading()
    {
        ?>
        <h1 class="screen-reader-text"><?php esc_attr_e( 'Main settings', 'furgonetka' ); ?></h1>
        <h2><?php esc_attr_e( 'Furgonetka', 'furgonetka' ); ?></h2>
        <p>
            <?php esc_attr_e( 'The Furgonetka.pl website enables the use of a wide range of courier services at very attractive prices without restrictions and the need to sign contracts.', 'furgonetka' ); ?>
            <br/>
            <?php esc_attr_e( 'We offer convenient tools that allow both companies and individuals to order quickly and conveniently courier.', 'furgonetka' ); ?>
            <br/>
            <?php esc_attr_e( 'This module will significantly improve the creation of shipments and ordering courier at Furgonetka.pl.', 'furgonetka' ); ?>
        </p>
        <?php
    }

    /**
     * Render admin heading fon inactive account
     *
     * @return void
     */
    public function render_admin_heading_for_inactive_account()
    {
        ?>
        <h2><?php esc_attr_e( 'Account', 'furgonetka' ); ?></h2>
        <p>
            <?php esc_attr_e( 'Please add new WOOCOMMERCE REST API read key and copy Consumer key and Consumer secret below.', 'furgonetka' ); ?>
            <a
                    href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=wc-settings&tab=advanced&section=keys&create-key=1' ) ); ?>"
                    target="_blank"
            >
                <?php esc_attr_e( 'Create new key', 'furgonetka' ); ?>
            </a>
            <br>
            <a
                    href="https://docs.woocommerce.com/document/woocommerce-rest-api/"
                    target="_blank"
            >
                <?php esc_attr_e( 'More info - https://docs.woocommerce.com/document/woocommerce-rest-api/', 'furgonetka' ); ?>
            </a>
        </p>
        <?php
    }

    /**
     * Render admin account summary
     *
     * @return void
     */
    public function render_admin_account_summary()
    {
        ?>
        <table class="form-table">
            <tbody>
                <tr>
                    <th scope="row">
                        <label for="balance"><?php esc_attr_e( 'Balance', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <input
                                name=""
                                type="text"
                                id="balance"
                                value="<?php echo esc_html( Furgonetka_Admin::get_client_balance() ); ?>"
                                class="regular-text"
                                required
                                disabled
                        >
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="clientID">
                            <?php esc_attr_e( 'Client ID', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <input
                                name=""
                                type="text"
                                id="clientID"
                                value="<?php echo esc_html( Furgonetka_Admin::get_cient_id() ); ?>"
                                class="regular-text"
                                required
                                disabled
                        >
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="clientSecret">
                            <?php esc_attr_e( 'Client Secret', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <input
                                name=""
                                type="text"
                                id="clientSecret"
                                value="<?php echo esc_html( Furgonetka_Admin::get_client_secret() ); ?>"
                                class="regular-text"
                                required
                                disabled
                        >
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="isTestMode">
                            <?php esc_attr_e( 'Test mode', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <input
                                name=""
                                type="checkbox"
                                id="isTestMode"
                                value="1"
                                <?php echo esc_html( Furgonetka_Admin::get_test_mode() ? 'checked' : '' ); ?>
                                disabled
                        >
                        <input
                                name="isTestMode"
                                type="hidden"
                                value="<?php echo esc_html( Furgonetka_Admin::get_test_mode() ? '1' : '' ); ?>"
                        >
                        <p class="description" id="home-description">
                            <?php esc_attr_e( 'Requires an account on', 'furgonetka' ); ?> http://sandbox.furgonetka.pl/
                        </p>
                    </td>
                </tr>
            </tbody>
        </table>
        <?php
    }

    /**
     * Render admin rester form
     *
     * @param  string $furgonetka_form_url - form url.
     * @param  string $tab_api_account     - account name.
     * @return void
     */
    public function render_admin_reset_form( $furgonetka_form_url, $tab_api_account )
    {
        ?>
        <form
                method="post"
                action="<?php echo esc_html( $furgonetka_form_url ) . '&tab=' . esc_html( $tab_api_account ); ?>"
        >
            <?php wp_nonce_field(); ?>
            <input type="hidden" name="furgonetkaAction" value="reset_credentials"/>
            <p>
                <?php esc_attr_e( 'You can reset current account by clicking Reset button', 'furgonetka' ); ?>
            </p>
            <table class="form-table">
                <p class="submit">
                    <input
                            type="submit"
                            name="submit"
                            id="submit"
                            class="button button-secondary"
                            value="<?php esc_attr_e( 'Reset', 'furgonetka' ); ?>"
                    >
                </p>
            </table>
        </form>
        <?php
    }

    /**
     * Render admin rester form
     *
     * @param  string $furgonetka_form_url - form url.
     * @param  string $tab_api_account     - account name.
     * @return void
     */
    public function render_admin_form_for_inactive_account( $furgonetka_form_url, $tab_api_account )
    {
        ?>
        <form
                method="post"
                action="<?php echo esc_html( $furgonetka_form_url ) . '&tab=' . esc_html( $tab_api_account ); ?>"
        >
        <?php wp_nonce_field(); ?>
            <input type="hidden" name="furgonetkaAction" value="create_integration"/>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row">
                            <label for="key_consumer_key">
                                <?php esc_attr_e( 'Consumer key', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="key_consumer_key"
                                    type="text"
                                    id="key_consumer_key"
                                    value=""
                                    class="regular-text"
                                    required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="key_consumer_secret">
                                <?php esc_attr_e( 'Consumer secret', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="key_consumer_secret"
                                    type="text"
                                    id="key_consumer_secret"
                                    value=""
                                    class="regular-text"
                                    required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="isTestMode">
                                <?php esc_attr_e( 'Test mode', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="isTestMode"
                                    type="checkbox"
                                    id="isTestMode"
                                    value="1"
                                    <?php echo esc_html( Furgonetka_Admin::get_test_mode() ) ? 'checked' : ''; ?>
                            >
                            <p class="description" id="home-description">
                                <?php esc_attr_e( 'Requires an account on', 'furgonetka' ); ?> http://sandbox.furgonetka.pl/
                            </p>
                        </td>
                    </tr>
                </tbody>
            </table>
            <p class="submit">
                <input
                        type="submit"
                        name="submit"
                        class="button button-primary"
                        value="<?php esc_attr_e( 'Save', 'furgonetka' ); ?>"
                >
            </p>
        </form>
        <?php
    }

    /**
     * Render admin account summary
     *
     * @return void
     */
    public function render_admin_button_placement( $portmonetka_form_url, $tab_api_account )
    {
        ?>
        <div>
            <label>
                <?php echo __( 'UUID integracji', 'furgonetka' ); ?>
                <input type="text" disabled value="<?php echo Furgonetka_Admin::get_checkout_uuid(); ?>">
            </label>
            <br>
            <br>
            <label>
                <input
                        type="checkbox"
                        disabled
                        <?php echo Furgonetka_Admin::is_checkout_active() ? 'checked' : ''; ?>
                >
                <?php echo __( 'Integracja aktywna', 'furgonetka' ); ?>
            </label>
            <br>
            <br>
            <label>
                <input
                        type="checkbox"
                        disabled
                        <?php echo ! empty( Furgonetka_Admin::is_checkout_test_mode() ) ? 'checked' : ''; ?>
                >
                <?php echo __( 'Tryb testowy', 'furgonetka' ); ?>
            </label>
        </div>
        <?php
    }
}
