<?php

/**
 * The file that defines view for api setting in cms
 *
 * @link  https://furgonetka.pl
 * @since 1.0.0
 *
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 */

/**
 * Class Furgonetka_Admin_Map_Details- views for Admin options page - Map settings
 *
 * @since      1.0.0
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 * @author     Furgonetka.pl <woocommerce@furgonetka.pl>
 */
class Furgonetka_Admin_Map_Details
{
    /**
     * Render heading
     *
     * @return void
     */
    public function render_heading()
    {
        ?>
        <h1 class="screen-reader-text"><?php esc_attr_e( 'Attach map to delivery option', 'furgonetka' ); ?></h1>
        <h2><?php esc_attr_e( 'Attach map to delivery option', 'furgonetka' ); ?></h2>
        <p>
            <?php esc_attr_e( 'Please remember! You can only attach map to flat rates delivery option. Every delivery option can have one map attached', 'furgonetka' ); ?>
        </p>
        <?php
    }
    /**
     * Render form
     *
     * @param  string $furgonetka_form_url - form url.
     * @param  string $tab_attach_map      - action name.
     * @return void
     */
    public function render_sender_info_form( $furgonetka_form_url, $tab_attach_map )
    {
        ?>
        <form method="post" action="<?php echo esc_html( $furgonetka_form_url . '&tab=' . $tab_attach_map ); ?>">
            <?php $delivery_to_type = get_option( FURGONETKA_PLUGIN_NAME . '_deliveryToType' ); ?>
            <?php wp_nonce_field(); ?>
            <input type="hidden" name="furgonetkaAction" value="save_delivery"/>
            <table class="form-table">
                <tbody>
                <tr>
                    <th scope="row">
                        <label for="inpost">
                            <?php esc_attr_e( 'Add InPost map to:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'inpost', $delivery_to_type ); ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="poczta">
                            <?php esc_attr_e( 'Add Poczta Polska map to:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'poczta', $delivery_to_type ); ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="kiosk">
                            <?php esc_attr_e( 'Add ORLEN Paczka map to:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'kiosk', $delivery_to_type ); ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="uap">
                            <?php esc_attr_e( 'Add UPS Access Point map to:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'uap', $delivery_to_type ); ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="dpd">
                            <?php esc_attr_e( 'Add DPD Pickup map to:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'dpd', $delivery_to_type ); ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="dhl">
                            <?php esc_attr_e( 'Add DHL Parcel map to:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'dhl', $delivery_to_type ); ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="fedex">
                            <?php esc_attr_e( 'Add FedEx Point map to:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'fedex', $delivery_to_type ); ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="gls">
                            <?php esc_attr_e( 'Add GLS Szybka Paczka map to*:', 'furgonetka' ); ?>
                        </label>
                    </th>
                    <td>
                        <?php Furgonetka_Admin::map_attach_to( 'gls', $delivery_to_type ); ?>
                        <p>
                            <?php esc_attr_e( '* Applies to own contracts in the ShopDeliveryService service', 'furgonetka' ); ?>
                        </p>
                    </td>
                </tr>
                </tbody>
            </table>
            <p class="submit">
                <input
                        type="submit"
                        name="submit"
                        class="button button-primary"
                        value="<?php esc_attr_e( 'Save', 'furgonetka' ); ?>"
                >
            </p>
        </form>
        <?php
    }
}
