<?php

/**
 * The file that defines view for admin sender information
 *
 * @link  https://furgonetka.pl
 * @since 1.0.0
 *
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 */

/**
 *  Class Furgonetka_Admin_Sender_info- views for Admin options page - Sender info
 *
 * @since      1.0.0
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 * @author     Furgonetka.pl <woocommerce@furgonetka.pl>
 */
class Furgonetka_Admin_Sender_info
{
    /**
     * Render heading
     *
     * @return void
     */
    public function render_heading()
    {
        ?>
        <h1 class="screen-reader-text"><?php esc_attr_e( 'Sender info', 'furgonetka' ); ?></h1>
        <h2><?php esc_attr_e( 'Sender info', 'furgonetka' ); ?></h2>
        <p><?php esc_attr_e( 'Complete the senders address details.', 'furgonetka' ); ?></p>
        <?php
    }
    /**
     * Render form
     *
     * @param  string $furgonetka_form_url - form url.
     * @param  string $tab_sender_info     - action name.
     * @return void
     */
    public function render_sender_info_form( $furgonetka_form_url, $tab_sender_info )
    {
        ?>
        <form
                method="post"
                action="<?php esc_html( $furgonetka_form_url ) . '&tab=' . esc_html( $tab_sender_info ); ?>"
        >
            <input type="hidden" name="furgonetkaAction" value="save_sender_data"/>
            <?php wp_nonce_field(); ?>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row">
                            <label for="name">
                                <?php esc_attr_e( 'Name', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="name"
                                    type="text"
                                    id="name"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_name() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>

                    <tr>
                        <th scope="row">
                            <label for="companyName">
                                <?php esc_attr_e( 'Company name', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="companyName"
                                    type="text"
                                    id="companyName"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_company_name() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="postCode">
                                <?php esc_attr_e( 'Post code', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="postCode"
                                    type="text"
                                    id="postCode"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_post_code() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="city">
                                <?php esc_attr_e( 'City', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="city"
                                    type="text"
                                    id="city"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_city() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="street">
                                <?php esc_attr_e( 'Address', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="street"
                                    type="text" id="street"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_street() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row"><label for="email">
                                <?php esc_attr_e( 'E-mail', 'furgonetka' ); ?></label></th>
                        <td><input
                                    name="email"
                                    type="text"
                                    id="email"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_sender_email() ); ?>"
                                    class="regular-text"
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="telephone">
                                <?php esc_attr_e( 'Phone', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="telephone"
                                    type="text"
                                    id="telephone"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_telephone() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="iban">
                                <?php esc_attr_e( 'Bank account number', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td><input
                                    name="iban"
                                    type="text"
                                    id="iban"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_iban() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>
                    <tr>
                        <th scope="row">
                            <label for="accountOwner">
                                <?php esc_attr_e( 'Bank account owner name', 'furgonetka' ); ?>
                            </label>
                        </th>
                        <td>
                            <input
                                    name="accountOwner"
                                    type="text"
                                    id="accountOwner"
                                    value="<?php echo esc_html( Furgonetka_Admin::get_account_owner() ); ?>"
                                    class="regular-text" required
                            >
                        </td>
                    </tr>
                </tbody>
            </table>
            <p class="submit">
                <input
                        type="submit"
                        name="submit"
                        class="button button-primary"
                        value="<?php esc_attr_e( 'Save', 'furgonetka' ); ?>"
                >
            </p>
        </form>
        <?php
    }
}
