<?php

/**
 * The file that defines view for Admin options page
 *
 * @link  https://furgonetka.pl
 * @since 1.0.0
 *
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 */

/**
 *  Class Furgonetka_Navigation - views for Admin options page - Navigation
 *
 * @since      1.0.0
 * @package    Furgonetka
 * @subpackage Furgonetka/includes/rest_api/endpoint_controller/view
 * @author     Furgonetka.pl <woocommerce@furgonetka.pl>
 */
class Furgonetka_Navigation
{
    /**
     * Render Nav
     *
     * @param  string $tab - tab name.
     * @return void
     */
    public function render_nav( $tab )
    {
        $nonce = wp_create_nonce();
        ?>
        <nav class="nav-tab-wrapper woo-nav-tab-wrapper">
            <a
                    href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=furgonetka&nonce=' . $nonce ) ); ?>"
                    class="nav-tab
                    <?php echo ( 'furgonetka' === $tab || ! isset( $tab ) ) ? 'nav-tab-active' : ''; ?>"
            >
                <?php esc_attr_e( 'API account', 'furgonetka' ); ?>
            </a>
            <?php if ( Furgonetka_Admin::is_account_active() ) : ?>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=sender_info&nonce=' . $nonce ) ); ?>"
                        class="nav-tab
                        <?php echo ( 'sender_info' === $tab ) ? 'nav-tab-active' : ''; ?>"
                >
                    <?php esc_attr_e( 'Sender info', 'furgonetka' ); ?>
                </a>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=attach_map&nonce=' . $nonce ) ); ?>"
                        class="nav-tab
                        <?php echo ( 'attach_map' === $tab ) ? 'nav-tab-active' : ''; ?>"
                >
                    <?php esc_attr_e( 'Attach map', 'furgonetka' ); ?>
                </a>
                <?php
                /*
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=portmonetka&nonce=' . $nonce ) ); ?>"
                        class="nav-tab <?php echo ( 'portmonetka' === $tab ) ? 'nav-tab-active' : ''; ?>"
                >
                    <?php esc_attr_e( 'Portmonetka', 'furgonetka' ); ?>
                </a>
                */
                ?>
                <a
                        href="<?php echo esc_html( get_admin_url( '', '/admin.php?page=furgonetka&tab=advanced_settings&nonce=' . $nonce ) ); ?>"
                        class="nav-tab
                        <?php echo ( 'advanced_settings' === $tab ) ? 'nav-tab-active' : ''; ?>"
                >
                    <?php esc_attr_e( 'Advanced', 'furgonetka' ); ?>
                </a>
            <?php endif; ?>
        </nav>
        <?php
    }

    /**
     * Render admin notice area
     *
     * @param  string $furgonetka_errors   - error message.
     * @param  string $furgonetka_messages - meassage.
     * @return void
     */
    public function render_admin_notices_area( $furgonetka_errors, $furgonetka_messages )
    {
        Furgonetka_Admin::print_messages( $furgonetka_errors, 'error' );
        Furgonetka_Admin::print_messages( $furgonetka_messages, 'message' );
    }
}
